@@ -1,6 +1,6 @@
 // ***************************************************************** -*- C++ -*-
 /*
- * Copyright (C) 2004-2018 Exiv2 authors
+ * Copyright (C) 2004-2021 Exiv2 authors
  * This program is part of the Exiv2 distribution.
  *
  * This program is free software; you can redistribute it and/or
@@ -17,15 +17,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
-/*!
-  @file    types.hpp
-  @brief   Type definitions for %Exiv2 and related functionality
-  @author  Andreas Huggel (ahu)
-           <a href="mailto:ahuggel@gmx.net">ahuggel@gmx.net</a>
-  @date    09-Jan-04, ahu: created<BR>
-           11-Feb-04, ahu: isolated as a component<BR>
-           31-Jul-04, brad: added Time, Data and String values
- */
 #ifndef TYPES_HPP_
 #define TYPES_HPP_
 
@@ -58,9 +49,7 @@
    typedef          __int64 int64_t;
 # endif
 #else
-  #ifdef EXV_HAVE_STDINT_H
   # include <stdint.h>
-  #endif
 #endif
 
 
